@@ -19,9 +19,7 @@ module Control.Monad.Base
   , liftBaseDefault
   ) where
 
-import Data.Monoid
 import Data.Functor.Identity
-import Control.Applicative (Applicative(..))
 import Control.Monad.Trans.Class
 import Control.Monad.Trans.Identity
 import Control.Monad.Trans.Maybe
@@ -36,10 +34,16 @@ import qualified Control.Monad.Trans.RWS.Strict as S
 import Control.Monad.Trans.Error
 import Control.Monad.Trans.Cont
 import Control.Monad.Trans.Except
+import Control.Monad.Trans.Accum
+import Control.Monad.Trans.Select
+#if !MIN_VERSION_base(4,8,0)
+import Data.Monoid
+import Control.Applicative (Applicative(..))
+#endif
 #if !MIN_VERSION_base(4,4,0) && HS_TRANSFORMERS_BASE__ORPHANS
-import Control.Monad (ap)
 import qualified Control.Monad.ST.Lazy as L
 import qualified Control.Monad.ST.Strict as S
+import Data.Orphans ()
 #endif
 #if MIN_VERSION_base(4,4,0)
 import qualified Control.Monad.ST.Lazy.Safe as L
@@ -65,14 +69,6 @@ BASE(Identity)
 BASE(STM)
 
 #if !MIN_VERSION_base(4,4,0) && HS_TRANSFORMERS_BASE__ORPHANS
-instance Applicative (L.ST s) where
-  pure  = return
-  (<*>) = ap
-
-instance Applicative (S.ST s) where
-  pure  = return
-  (<*>) = ap
-
 BASE(L.ST s)
 BASE(S.ST s)
 #endif
@@ -101,6 +97,7 @@ TRANS(L.StateT s)
 TRANS(S.StateT s)
 TRANS(ContT r)
 TRANS(ExceptT e)
+TRANS(SelectT r)
 #undef TRANS
 
 #define TRANS_CTX(CTX, T) \
@@ -111,4 +108,5 @@ TRANS_CTX(Monoid w, S.WriterT w)
 TRANS_CTX(Monoid w, L.RWST r w s)
 TRANS_CTX(Monoid w, S.RWST r w s)
 TRANS_CTX(Error e,  ErrorT e)
+TRANS_CTX(Monoid w, AccumT w)
 #undef TRANS_CTX
